/* This file is part of herzi's playground
 *
 * Copyright (C) 2010  Sven Herzberg
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include "fw-client.h"

#include <dbus/dbus.h>

int
main (int   argc,
      char**argv)
{
  DBusGConnection* bus;
  DBusGProxy     * proxy;
  GError         * error = NULL;
  gchar          * out = NULL;

  g_type_init ();

  bus = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);

  if (error)
    {
      g_warning ("error getting system bus: %s", error->message);
      g_error_free (error);
      return 1;
    }

  if (!bus)
    {
      g_warning ("system bus is NULL");
      return 2;
    }

  proxy = dbus_g_proxy_new_for_name_owner (bus,
                                           "org.fedoraproject.Config.Firewall",
                                           "/org/fedoraproject/Config/Firewall",
                                           "org.fedoraproject.Config.Firewall",
                                           &error);

  if (error)
    {
      g_warning ("error getting proxy: %s",
                 error->message);
      return 1;
    }

  if (!org_fedoraproject_Config_Firewall_read (proxy, &out, &error))
    {
      g_warning ("error while calling \"org_fedoraproject_Config_Firewall_read()\": %s",
                 error->message);
      g_error_free (error);
    }
  else
    {
      g_print ("Firewall configuration:\n%s\n", out);
      g_free (out);
    }

  dbus_g_connection_unref (bus);

  return 0;
}

/* vim:set et sw=2 cino=t0,f0,(0,{s,>2s,n-1s,^-1s,e2s: */
